import ancestor from "common-ancestor-path";
import { isPage, isEndpoint } from "../core/util.js";
import { scan } from "./scan.js";
function astroScannerPlugin({ settings, logging }) {
  function normalizeFilename(filename) {
    if (filename.startsWith("/@fs")) {
      filename = filename.slice("/@fs".length);
    } else if (filename.startsWith("/") && !ancestor(filename, settings.config.root.pathname)) {
      filename = new URL("." + filename, settings.config.root).pathname;
    }
    return filename;
  }
  return {
    name: "astro:scanner",
    enforce: "post",
    async transform(code, id, options) {
      if (!(options == null ? void 0 : options.ssr))
        return;
      const filename = normalizeFilename(id);
      let fileURL;
      try {
        fileURL = new URL(`file://${filename}`);
      } catch (e) {
        return;
      }
      const fileIsPage = isPage(fileURL, settings);
      const fileIsEndpoint = isEndpoint(fileURL, settings);
      if (!(fileIsPage || fileIsEndpoint))
        return;
      const pageOptions = await scan(code, id);
      const { meta = {} } = this.getModuleInfo(id) ?? {};
      return {
        code,
        meta: {
          ...meta,
          astro: {
            ...meta.astro ?? { hydratedComponents: [], clientOnlyComponents: [], scripts: [] },
            pageOptions
          }
        }
      };
    }
  };
}
export {
  astroScannerPlugin as default
};
