import * as eslexer from "es-module-lexer";
import { AstroError, AstroErrorData } from "../core/errors/index.js";
const BOOLEAN_EXPORTS = /* @__PURE__ */ new Set(["prerender"]);
function includesExport(code) {
  for (const name of BOOLEAN_EXPORTS) {
    if (code.includes(name))
      return true;
  }
  return false;
}
let didInit = false;
async function scan(code, id) {
  if (!includesExport(code))
    return {};
  if (!didInit) {
    await eslexer.init;
    didInit = true;
  }
  const [_, exports] = eslexer.parse(code, id);
  let pageOptions = {};
  for (const _export of exports) {
    const { n: name, le: endOfLocalName } = _export;
    if (BOOLEAN_EXPORTS.has(name)) {
      let expr = code.slice(endOfLocalName).trim().replace(/\=/, "").trim().split(/[;\n]/)[0];
      if (!(expr === "true" || expr === "false")) {
        throw new AstroError({
          ...AstroErrorData.InvalidPrerenderExport,
          message: AstroErrorData.InvalidPrerenderExport.message(expr),
          location: { file: id }
        });
      } else {
        pageOptions[name] = expr === "true";
      }
    }
  }
  return pageOptions;
}
export {
  scan
};
